==> use-popper-0.0.2.tgz: package/dist-src/index.js <==
import Popper from 'popper.js';
import React from 'react';
import usePopperState from "./usePopperState.js";

function usePopper({
  placement = 'bottom',
  positionFixed = false,
  eventsEnabled = true,
  modifiers = {}
}) {
  const popperInstance = React.useRef(null);
  const [popperStyles, updatePopperState] = usePopperState(placement);
  const [referrenceNode, referrenceRef] = React.useState(null);
  const [popperNode, popperRef] = React.useState(null);
  const [arrowNode, arrowRef] = React.useState(null);
  React.useEffect(() => {
    if (popperInstance.current !== null) {
      popperInstance.current.destroy();
    }

    if (referrenceNode === null || popperNode === null) return; // @ts-ignore

    popperInstance.current = new Popper(referrenceNode, popperNode, {
      placement,
      positionFixed,
      modifiers: { ...modifiers,
        arrow: { ...(modifiers && modifiers.arrow),
          enabled: Boolean(arrowNode),
          element: arrowNode
        },
        applyStyle: {
          enabled: false
        },
        updateStateModifier: {
          enabled: true,
          order: 900,
          fn: updatePopperState
        }
      }
    });
    return () => {
      if (popperInstance.current !== null) {
        popperInstance.current.destroy();
      }
    };
  }, [arrowNode, referrenceNode, popperNode, placement, positionFixed, modifiers]);
  React.useEffect(() => {
    if (!popperInstance.current) return;

    if (eventsEnabled) {
      popperInstance.current.enableEventListeners();
    } else {
      popperInstance.current.disableEventListeners();
    }
  }, [eventsEnabled, popperInstance.current]);
  React.useEffect(() => {
    if (popperInstance.current) {
      popperInstance.current.scheduleUpdate();
    }
  });
  return {
    placement: popperStyles.placement,
    referrence: {
      ref: referrenceRef
    },
    popper: {
      ref: popperRef,
      styles: popperStyles.popperStyles
    },
    arrow: {
      ref: arrowRef,
      styles: popperStyles.arrowStyles
    }
  };
}

export default usePopper;

==> use-popper-0.0.3.tgz: package/dist-src/index.js <==
import Popper from 'popper.js';
import React from 'react';
import usePopperState from "./usePopperState.js";

function usePopper({
  placement = 'bottom',
  positionFixed = false,
  eventsEnabled = true,
  modifiers = {}
}) {
  const popperInstance = React.useRef(null);
  const [popperStyles, updatePopperState] = usePopperState(placement);
  const [referrenceNode, referrenceRef] = React.useState(null);
  const [popperNode, popperRef] = React.useState(null);
  const [arrowNode, arrowRef] = React.useState(null);
  React.useEffect(() => {
    if (popperInstance.current !== null) {
      popperInstance.current.destroy();
    }

    if (referrenceNode === null || popperNode === null) return; // @ts-ignore

    popperInstance.current = new Popper(referrenceNode, popperNode, {
      placement,
      positionFixed,
      modifiers: { ...modifiers,
        arrow: { ...(modifiers && modifiers.arrow),
          enabled: Boolean(arrowNode),
          element: arrowNode
        },
        applyStyle: {
          enabled: false
        },
        updateStateModifier: {
          enabled: true,
          order: 900,
          fn: updatePopperState
        }
      }
    });
    return () => {
      if (popperInstance.current !== null) {
        popperInstance.current.destroy();
      }
    };
  }, [arrowNode, referrenceNode, popperNode, placement, positionFixed, modifiers]);
  React.useEffect(() => {
    if (popperInstance.current === null) return;

    if (eventsEnabled) {
      popperInstance.current.enableEventListeners();
    } else {
      popperInstance.current.disableEventListeners();
    }
  }, [eventsEnabled]);
  React.useEffect(() => {
    if (popperInstance.current !== null) {
      popperInstance.current.scheduleUpdate();
    }
  });
  return {
    placement: popperStyles.placement,
    referrence: {
      ref: referrenceRef
    },
    popper: {
      ref: popperRef,
      styles: popperStyles.popperStyles
    },
    arrow: {
      ref: arrowRef,
      styles: popperStyles.arrowStyles
    }
  };
}

export default usePopper;
